@@ -1,16 +1,15 @@
 class pckg:
     def __init__(self):
-        print("Hello Welsomce to ustav Library.")
+        print("Hello Welcome to utsav Library.")
         
-    def sum(num1,num2):
-
+    def sum(self,num1,num2):
         return num1 + num2
 
-    def sub(num1,num2):
+    def sub(self,num1,num2):
         return num1 - num2
 
-    def mul(num1,num2):
+    def mul(self,num1,num2):
         return num1 * num2
     
-    def div(num1,num2):
+    def div(self,num1,num2):
         return num1 / num2
